##############################################################################
#
# Copyright (c) 2006 Serge CASA
# All rights reserved. Written by Serge CASA 
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted under the ZPL license
#
#   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR 
#   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
#   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
#   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, 
#   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
#   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
#   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
#   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
#   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF 
#   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
#
# Thanks to Dean Jenkins for his release of BannerDepository as a Zclass, from which this product is fully inspired
# The ZClass product of Dean Jenkins is available from <a href="http://www.zope.org/Members/dean.jenkins/BannerDepository">www.zope.org</a>
# This product is available from <a href="http://www.zope.org/Members/senacle/BannerDepository">www.zope.org</a>
#
##############################################################################

__doc__="""BannerAdvert - Part of BannerAdManager product"""

__version__='$Revision: 1.0 $'[11:-2]

##############################################################################

from Acquisition import Implicit
from Globals import Persistent
from AccessControl.Role import RoleManager
import Globals
import AccessControl
from OFS.ObjectManager import ObjectManager
from OFS.PropertyManager import PropertyManager
from OFS.SimpleItem import Item
from OFS.Folder import Folder					# pour parametre de la classe BannerDepository qui permet d'afficher le contenu dans l'onglet Contents

class BannerAdvert(Folder, Implicit, Persistent, RoleManager, Item, ObjectManager, PropertyManager):
    
	"""Object representing a bannerad"""

	meta_type='BannerAdvert'
	all_meta_types = meta_types = (
        {'name': 'Image', 'action': 'manage_addProduct/OFSP/imageAdd'},
    )
	
	redirect = Globals.DTMLFile('dtml/redirect_ad', globals())
	pop_up_html = Globals.DTMLFile('dtml/pop_up_html_ad', globals())
	show_image = Globals.DTMLFile('dtml/show_image_ad', globals())
	show_image_compatible_js = Globals.DTMLFile('dtml/show_image_compatible_js_ad', globals())
	show_stats = Globals.DTMLFile('dtml/show_stats_ad', globals())
	test = Globals.DTMLFile('dtml/test_ad', globals())

	#Management screen
	#the standard management view defined by RoleManager is Security and those defined by Item are Undo and Ownership
	manage_options=(
		{'label':'Contents', 'action':'manage_main', 'help':('BannerAdManager','BannerImages.stx')},	# manage_main provient de ObjectManager
		{'label':'Test', 'action':'test','help':('BannerAdManager','Information_Ad.stx')},
		{'label':'Show Advert Stats', 'action':'show_stats','help':('BannerAdManager','BannerStats.stx')},
		{'label':'Properties', 'action': 'manage_propertiesForm','help':('BannerAdManager','BannerAdProperties.stx')},	# 
		)+ RoleManager.manage_options + Item.manage_options

	# __ac_permissions__ = (
		# ('View', ('',)),
	# )

	_properties=(
		{'id':'link_code', 'type': 'string', 'mode':'w'},
		{'id':'initial_views', 'type': 'int', 'mode':'w'},
		{'id':'views', 'type': 'int', 'mode':'w'},
		{'id':'remaining_views', 'type': 'int', 'mode':'w'},
		{'id':'alt', 'type': 'string', 'mode':'w'},
		{'id':'weight', 'type': 'int', 'mode':'w'},
		{'id':'click_thrus', 'type': 'int', 'mode':'w'},
		{'id':'border', 'type': 'int', 'mode':'w'},
	)
	
	link_code = '/'
	initial_views = 1000000
	views = 0
	remaining_views = 1000000
	alt = 'Visitez notre sponsor !'
	weight = 1
	click_thrus = 0
	border = 0
	
	# Security
	security = AccessControl.ClassSecurityInfo()
    
	def __init__(self, id):
		self.id = id
	
# call this to initialize framework classes, which
# does the right thing with the security assertions.
Globals.default__class_init__(BannerAdvert)

manage_BannerAdvert_addForm = Globals.DTMLFile('dtml/addBannerAdvertForm', globals())

def manage_BannerAdvert_add(self, id, REQUEST=None):

    """ Adds a BannerAdvert to a BannerDepository folder. """
	
    newBannerAdvert = BannerAdvert(id)
    self._setObject(id, newBannerAdvert)
    if REQUEST is not None:
		return self.manage_main(self, REQUEST)