##############################################################################
#
# Copyright (c) 2006 Serge CASA
# All rights reserved. Written by Serge CASA 
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted under the ZPL license
#
#   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR 
#   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
#   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
#   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, 
#   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
#   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
#   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
#   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
#   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF 
#   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
#
# Thanks to Dean Jenkins for his release of BannerDepository as a Zclass, from which this product is fully inspired
# The ZClass product of Dean Jenkins is available from <a href="http://www.zope.org/Members/dean.jenkins/BannerDepository">www.zope.org</a>
# This product is available from <a href="http://www.zope.org/Members/senacle/BannerDepository">www.zope.org</a>
#
##############################################################################

__doc__="""BannerDepository - Part of BannerAdManager product"""

__version__='$Revision: 1.0 $'[11:-2]

##############################################################################

from Acquisition import Implicit				# pour parametre de la classe BannerDepository
from Globals import Persistent					# pour parametre de la classe BannerDepository
from AccessControl.Role import RoleManager		# pour parametre de la classe BannerDepository
import Globals									# pour DTMLFile
import AccessControl							# pour Security
from OFS.ObjectManager import ObjectManager		# pour parametre de la classe BannerDepository qui gere l'onglet Contents
from OFS.PropertyManager import PropertyManager	# pour parametre de la classe BannerDepository qui gere l'onglet Properties
from BannerAdvert import *						# pour pouvoir ajouter uniquement un objet BannerAdvert dans un BannerDepository
from OFS.SimpleItem import Item					# pour parametre de la classe BannerDepository
from OFS.Folder import Folder					# pour parametre de la classe BannerDepository qui permet d'afficher le contenu dans l'onglet Contents

class BannerDepository(Folder, Implicit, Persistent, RoleManager, Item, ObjectManager, PropertyManager):
    
	"""Object representing a bannerdepository"""

	meta_type='BannerDepository'								# Nom qui apparait dans la liste des objets que l'on peut ajouter dans la ZMI
	manage_BannerAdvert_addForm = manage_BannerAdvert_addForm	# le deuxieme terme provient de l'import de BannerAdvert
	manage_BannerAdvert_add = manage_BannerAdvert_add
	# Pour n'afficher que l'objet BannerAdvert dans la liste des objets disponibles, j'ai surcharge la methode all_meta_types() de la classe ObjectManager de cette maniere :
	all_meta_types = meta_types = (
        {'name': 'Banner Advert', 'action': 'manage_BannerAdvert_addForm'},
    )

	# Security
	security = AccessControl.ClassSecurityInfo()

	# declaration of dtml
	show_banner = Globals.DTMLFile('dtml/show_banner_depository', globals())
	security.declareProtected('View management screens', 'show_stats')
	show_stats = Globals.DTMLFile('dtml/show_stats_depository', globals())
	security.declareProtected('View management screens', 'test')
	test = Globals.DTMLFile('dtml/test_depository', globals())

	# Management Screens
	#the standard management view defined by RoleManager is Security and those defined by Item are Undo and Ownership
	manage_options=(
		{'label':'Contents', 'action':'manage_main', 'help':('BannerAdManager','BannerDepository.stx')},	# manage_main provient de ObjectManager
		{'label':'Test', 'action':'test'},
		{'label':'Show Depository Stats', 'action':'show_stats','help':('BannerAdManager','BannerStats.stx')},
		{'label': 'Properties', 'action': 'manage_propertiesForm','help':('BannerAdManager','BannerBepositoryProperties.stx')},	# manage_propertiesForm provient de PropertyManager
		) + Item.manage_options + RoleManager.manage_options 
	
	# Properties
	_properties=(
		{'id':'new_window', 'type': 'boolean', 'mode':'w'},
		{'id':'pop_up', 'type': 'boolean', 'mode':'w'},
		)
	# pour que les proprietes soient prises en compte, il faut les initailiser.
	new_window = 1
	pop_up = 0
	
	
	__ac_permissions__ =(
				('Manage properties', ('manage_addProperty','manage_editProperties', 'manage_delProperties', 'manage_changeProperties',)),
				('View management screens', ('manage', 'manage_main')),
				)

	def __init__(self, id):
		self.id = id
	
# call this to initialize framework classes, which does the right thing with the security assertions.
Globals.default__class_init__(BannerDepository)
	
manage_BannerDepository_addForm = Globals.DTMLFile('dtml/addBannerDepositoryForm', globals())
	
def manage_BannerDepository_add(self, id='', title='', REQUEST=None):

    """ Adds a BannerDepository to a folder. """
	
    newBannerDepository = BannerDepository(id)
    self._setObject(id, newBannerDepository)
    if REQUEST is not None:
		return self.manage_main(self, REQUEST)